summaryrefslogtreecommitdiffstats
path: root/webkit
diff options
context:
space:
mode:
authordpranke@google.com <dpranke@google.com@0039d316-1c4b-4281-b951-d872f2087c98>2009-11-16 00:16:49 +0000
committerdpranke@google.com <dpranke@google.com@0039d316-1c4b-4281-b951-d872f2087c98>2009-11-16 00:16:49 +0000
commite76f29692595c652b11066cfb404ed2a8fecaf68 (patch)
tree92555415f812659861c16067078d9ae24a7e11c1 /webkit
parent643319572395cb7d9519025ff7c9cf998c38ebdf (diff)
downloadchromium_src-e76f29692595c652b11066cfb404ed2a8fecaf68.zip
chromium_src-e76f29692595c652b11066cfb404ed2a8fecaf68.tar.gz
chromium_src-e76f29692595c652b11066cfb404ed2a8fecaf68.tar.bz2
Tweak dashboard code to work out of the box with either local builds or
the bots. If you add '#buildDir=Debug' or '#buildDir=Release' to the URL it will load files from 'src/webkit/$buildDir/layout-test-results'. BUG=none R=ojan@chromium.org TEST=none Review URL: http://codereview.chromium.org/391041 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@32035 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'webkit')
-rw-r--r--webkit/tools/layout_tests/dashboards/dashboard_base.js21
1 files changed, 15 insertions, 6 deletions
diff --git a/webkit/tools/layout_tests/dashboards/dashboard_base.js b/webkit/tools/layout_tests/dashboards/dashboard_base.js
index 3813df5..7ec9eef 100644
--- a/webkit/tools/layout_tests/dashboards/dashboard_base.js
+++ b/webkit/tools/layout_tests/dashboards/dashboard_base.js
@@ -79,11 +79,18 @@ function handleValidHashParameterWrapper(key, value) {
case 'useWebKitCanary':
case 'useV8Canary':
- case 'debug':
currentState[key] = value == 'true';
-
return true;
+ case 'buildDir':
+ currentState['testType'] = 'layout-test-results';
+ if (value === 'Debug' || value == 'Release') {
+ currentState[key] = value;
+ return true;
+ } else {
+ return false;
+ }
+
default:
return handleValidHashParameter(key, value);
}
@@ -93,7 +100,7 @@ var defaultCrossDashboardStateValues = {
testType: 'layout_test_results',
useWebKitCanary: false,
useV8Canary: false,
- debug: false
+ buildDir : '',
}
// Generic utility functions.
@@ -183,11 +190,13 @@ var currentState;
parseParameters();
var builders, builderBase;
-if (currentState.debug) {
- // In debug mode point to the results.json and expectations.json in the
+if (currentState.buildDir) {
+ // If buildDir is set, point to the results.json and expectations.json in the
// local tree. Useful for debugging changes to the python JSON generator.
builders = {'DUMMY_BUILDER_NAME': ''};
- builderBase = '../../Debug/';
+ var loc = document.location.toString();
+ var offset = loc.indexOf('webkit/');
+ builderBase = loc.substr(loc, offset + 7) + currentState.buildDir + "/";
} else {
// Map of builderName (the name shown in the waterfall)
// to builderPath (the path used in the builder's URL)